@@ -9,7 +9,7 @@ use Dancer2::Plugin;
 use I18N::AcceptLanguage;
 use Locale::Wolowitz;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 my $wolowitz;
 
@@ -86,10 +86,10 @@ templates you can use the C<l('')> function
 register loc => \&_loc;
 
 sub _loc {
-    my ($dsl, $str, $args) = @_;
+    my ($dsl, $str, $args, $force_lang) = @_;
 
     $wolowitz ||= Locale::Wolowitz->new(_path_directory_locale($dsl));
-    my $lang    = _lang($dsl);
+    my $lang    = $force_lang || _lang($dsl);
 
     return $wolowitz->loc($str, $lang, @$args);
 };
